@@ -10,8 +10,11 @@ from zipfile import ZipFile
 from io import BytesIO
 
 import numpy as np
+import pytest
 
 from pytest import raises, skip
+
+from imageio.core.functions import to_nbytes
 from imageio.testing import run_tests_if_main, get_test_dir, need_internet
 
 import imageio
@@ -438,7 +441,6 @@ def test_util_image_as_uint():
     raises(ValueError, core.image_as_uint, 4)
     raises(ValueError, core.image_as_uint, "not an image")
     raises(ValueError, core.image_as_uint, np.array([0, 1]), bitdepth=13)
-    raises(ValueError, core.image_as_uint, np.array([2.0, 2.0], "float32"))
     raises(ValueError, core.image_as_uint, np.array([0.0, np.inf], "float32"))
     raises(ValueError, core.image_as_uint, np.array([-np.inf, 0.0], "float32"))
 
@@ -620,6 +622,47 @@ def test_functions():
     raises(ValueError, imageio.mvolsave, fname6, [42])
 
 
+@pytest.mark.parametrize(
+    "arg,expected",
+    [
+        (1, 1),
+        ("1", 1),
+        ("8B", 8),
+        ("1MB", 1000 ** 2),
+        ("1M", 1000 ** 2),
+        ("1GiB", 1024 ** 3),
+        ("1.5TB", 1.5 * 1000 ** 4),
+    ],
+)
+def test_to_nbytes_correct(arg, expected):
+    n = to_nbytes(arg)
+    assert n == expected
+
+
+@pytest.mark.parametrize("arg", ["1mb", "1Giib", "GB", "1.3.2TB", "8b"])
+def test_to_nbytes_incorrect(arg):
+    with raises(ValueError):
+        to_nbytes(arg)
+
+
+def test_memtest():
+    fname3 = get_remote_file("images/newtonscradle.gif", test_dir)
+    imageio.mimread(fname3)  # trivial case
+    imageio.mimread(fname3, memtest=1000 ** 2 * 256)
+    imageio.mimread(fname3, memtest="256MB")
+    imageio.mimread(fname3, memtest="256M")
+    imageio.mimread(fname3, memtest="256MiB")
+
+    # low limit should be hit
+    with raises(RuntimeError):
+        imageio.mimread(fname3, memtest=10)
+    with raises(RuntimeError):
+        imageio.mimread(fname3, memtest="64B")
+
+    with raises(ValueError):
+        imageio.mimread(fname3, memtest="64b")
+
+
 def test_example_plugin():
     """ Test the example plugin """
 
