@@ -148,6 +148,18 @@ def test_png():
     im2 = imageio.imread(fnamebase + "1.png")
     assert im2.dtype == np.uint16
 
+    # issue #352 - prevent low-luma uint16 truncation to uint8
+    arr = np.full((32, 32), 255, dtype=np.uint16)  # values within range of uint8
+    preferences_dtypes = [
+        [{}, np.uint8],
+        [{"prefer_uint8": True}, np.uint8],
+        [{"prefer_uint8": False}, np.uint16],
+    ]
+    for preference, dtype in preferences_dtypes:
+        imageio.imwrite(fnamebase + ".png", arr, **preference)
+        im = imageio.imread(fnamebase + ".png")
+        assert im.dtype == dtype
+
 
 def test_png_remote():
     # issue #202
